@@ -26,7 +26,7 @@ __version__ = "$Id: action.py 312 2007-04-09 19:45:49Z wrobel $"
 
 import os, sys
 
-from   layman.dbbase            import UnknownOverlayException, BrokenOverlayCatalog
+from   layman.dbbase            import UnknownOverlayException
 from   layman.db                import DB, RemoteDB
 from   layman.utils             import path, delete_empty_directory
 from   layman.debug             import OUT
@@ -367,7 +367,45 @@ class Info:
 #
 #-------------------------------------------------------------------------------
 
-class List:
+class List(object):
+    def __init__(self, config, db):
+        self.config = config
+        self.db = db
+
+    def _run(self, complain):
+        for summary, supported, official \
+                in self.db.list(self.config['verbose'], self.config['width']):
+            # Is the overlay supported?
+            if supported:
+                # Is this an official overlay?
+                if official:
+                    OUT.info(summary, 1)
+                # Unofficial overlays will only be listed if we are not
+                # checking or listing verbose
+                elif complain:
+                    # Give a reason why this is marked yellow if it is a verbose
+                    # listing
+                    if self.config['verbose']:
+                        OUT.warn('*** This is no official gentoo overlay ***\n', 1)
+                    OUT.warn(summary, 1)
+            # Unsupported overlays will only be listed if we are not checking
+            # or listing verbose
+            elif complain:
+                # Give a reason why this is marked red if it is a verbose
+                # listing
+                if self.config['verbose']:
+                    OUT.error('*** You are lacking the necessary tools '
+                              'to install this overlay ***\n')
+                OUT.error(summary)
+
+
+#===============================================================================
+#
+# Class ListRemote
+#
+#-------------------------------------------------------------------------------
+
+class ListRemote(List):
     ''' Lists the available overlays.
 
     >>> import os
@@ -383,8 +421,8 @@ class List:
     ...           'width':80,
     ...           'svn_command':'/usr/bin/svn',
     ...           'rsync_command':'/usr/bin/rsync'}
-    >>> a = List(config)
-    >>> a.rdb.cache()
+    >>> a = ListRemote(config)
+    >>> a.db.cache()
     >>> OUT.color_off()
     >>> a.run()
     * wrobel                    [Subversion] (https://o.g.o/svn/dev/wrobel         )
@@ -417,38 +455,16 @@ class List:
     '''
 
     def __init__(self, config):
-
         OUT.debug('Creating RemoteDB handler', 6)
-
-        self.rdb    = RemoteDB(config)
-        self.config = config
+        super(ListRemote, self).__init__(config, RemoteDB(config))
 
     def run(self):
         ''' List the available overlays.'''
 
-        for i in self.rdb.list(self.config['verbose'], self.config['width']):
-            # Is the overlay supported?
-            if i[1]:
-                # Is this an official overlay?
-                if i[2]:
-                    OUT.info(i[0], 1)
-                # Unofficial overlays will only be listed if we are not
-                # checking or listing verbose
-                elif self.config['nocheck'] or self.config['verbose']:
-                    # Give a reason why this is marked yellow if it is a verbose
-                    # listing
-                    if self.config['verbose']:
-                        OUT.warn('*** This is no official gentoo overlay ***\n', 1)
-                    OUT.warn(i[0], 1)
-            # Unsupported overlays will only be listed if we are not checking
-            # or listing verbose
-            elif self.config['nocheck'] or self.config['verbose']:
-                # Give a reason why this is marked red if it is a verbose
-                # listing
-                if self.config['verbose']:
-                    OUT.error('*** You are lacking the necessary tools to insta'
-                              'll this overlay ***\n')
-                OUT.error(i[0])
+        OUT.debug('Printing remote overlays.', 8)
+
+        _complain = self.config['nocheck'] or self.config['verbose']
+        self._run(complain=_complain)
 
         return 0
 
@@ -458,42 +474,19 @@ class List:
 #
 #-------------------------------------------------------------------------------
 
-class ListLocal:
+class ListLocal(List):
     ''' Lists the local overlays.'''
 
     def __init__(self, config):
-        self.db = DB(config)
-        self.config = config
+        OUT.debug('Creating DB handler', 6)
+        super(ListLocal, self).__init__(config, DB(config))
 
     def run(self):
         '''List the overlays.'''
 
-        for i in self.db.list(self.config['verbose']):
+        OUT.debug('Printing local overlays.', 8)
 
-            OUT.debug('Printing local overlay.', 8)
-
-            # Is the overlay supported?
-            if i[1]:
-                # Is this an official overlay?
-                if i[2]:
-                    OUT.info(i[0], 1)
-                # Unofficial overlays will only be listed if we are not
-                # checking or listing verbose
-                else:
-                    # Give a reason why this is marked yellow if it is a verbose
-                    # listing
-                    if self.config['verbose']:
-                        OUT.warn('*** This is no official gentoo overlay ***\n', 1)
-                    OUT.warn(i[0], 1)
-            # Unsupported overlays will only be listed if we are not checking
-            # or listing verbose
-            else:
-                # Give a reason why this is marked red if it is a verbose
-                # listing
-                if self.config['verbose']:
-                    OUT.error('*** You are lacking the necessary tools to insta'
-                              'll this overlay ***\n')
-                OUT.error(i[0])
+        self._run(complain=True)
 
         return 0
 
@@ -513,7 +506,7 @@ def main(config):
                ('info',       Info),
                ('sync_all',   Sync),
                ('delete',     Delete),
-               ('list',       List),
+               ('list',       ListRemote),
                ('list_local', ListLocal),]
 
     if True:  # A hack to save diff with indentation changes only
